% This Matlab script can be used to load, analyze and visualze the data
% used in the manuscript named "How do driving modes affect the vehicles
% dynamic behaviour? Comparing Renaults Multi-Sense Sport and Comfort
% modes during on-road naturalistic driving."
% published in the Vehicle system dynamics journal

% T. Melman September 2019
% timo.melman@renault.com, t.melman@tudelft.nl
clc
close all
clearvars -except strc % The data structure that only needs to be loaded once

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Initialization
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Names of the two data files:
Exp.name{1}    = 'RuralRoad'; 
Exp.name{2}    = 'Highway';

% Names of the conditions
Exp.condition  = {'Sport' 'Comfort'};

% Data directories
home                             = pwd;
% Functions developed by T. Melman are included here:
addpath(genpath([home '\UsedFunctions']));
addpath(genpath([home '\Data'])); % Data not automatically available

% Experiment information
Exp.total_sub         = 1; % Number of subjects
Exp.total_cond        = length(Exp.condition); % Number of conditions
Exp.total_rep         = 4; % Number of repetitions

% Dock the output figures in the window by default
set(0,'DefaultFigureWindowStyle','docked');

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Load data files
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Load both route files and store into one structure named 'strc'.
% - The two routes are stored as strc.Experiment{1} = Rural road, and
%      strc.Experiment{2} = Highway.
% - strc.Experiment{1}.sub(1).cond(1).Rep(:) contains for all four
%      repetitions the time signal for all recorded CAN signals
% - strc.Experiment{1}.CombinedData contains for both conditions (sport
%      and comfort) the averaged data over all four repetitions as function 
%      of travelled distance.

MatAlreadyExist = exist('strc','var');
if ~MatAlreadyExist
    for i = 1:length(Exp.name)
        disp(['Loading data of ' sprintf('strc_%s',Exp.name{i}) '...'])
        eval(sprintf('load strc_%s',Exp.name{i}));   % Load Experiment data
        eval(sprintf('strc.Experiment{i} = strc_%s',Exp.name{i})); % Rename Experiemnt data as "strc" getStandardMetrics
    end
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Make plots used in VSDJ paper
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% "SignalCheck" Creates the cohen's d rating for all CAN signals and
% visualizes them (Figure 6 and 7 in paper). Signalcheck also plots
% the raw time signal used in Figure 4 and 5 of the paper.
SignalCheck( strc, 'RuralRoad' ); % For Rural road
SignalCheck( strc, 'Highway' ); % For Highway
disp('** Finished making the cohen''s d ranking')

% Create the slope figures (Figures 9b - 11b)
disp('** Start plotting Figure 9 - 12')
CreateSlopePlots( strc, Exp );

% Create plot for two speed bins (Figure 9a - 11a)
CreateSpeedBinPlots( strc );

% Create Longitudinal dynamic plot (Figure 12)
CreateLongDynamicPlots( strc );

% Create Table 2
disp('** Start creating Table 2')
CreateTable2( strc );

% Qcar Optimization and plot
disp('** Start Qcar optimization and create figure')
QcarOptimisation();

% Plot Appendix figure - 'explain cohen d'
Data = zeros(4,2);
for i = 1:4
    Data(i,1) = std(strc.Experiment{2}.sub(1).cond(1).rep(i).RearWheelAnglePosit);
    Data(i,2) = std(strc.Experiment{2}.sub(1).cond(2).rep(i).RearWheelAnglePosit);
end
plt_error_bars_cohenD( Data,  'Task', 'SD Rear wheel angle (deg)',...
    Exp.condition,0.1,true,false);

% Done
disp('** End of script')